# Authors: Eric Larson <larson.eric.d@gmail.com>
# License: BSD-3-Clause
# Copyright the MNE-Python contributors.

from .commands.utils import main

if __name__ == "__main__":
    main()
